//+------------------------------------------------------------------+
//|                                           Scalp Based on ATR.mq5 |
//|                        Copyright 2020, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"

#include <Trade/Trade.mqh>
CTrade trade;

input string               p00                        ="";           //=====General SETTINGS=========
input double LotSize = -1;   //"-1" means Balance/100
input int MagicNumber = 65262;
input int Slippage = 1;  //Slippage in pips
input int TakeProfit = 2; //Take Profit in pips
input int StopLoss = 0; //Stop Loss in pips
input int allowedposition = 1; // Allowed Open position for a Symbol
input double spread =0; // Spread ["0" for Current spread]

input string               p01                        ="";           //=====STOCHASTIC SETTINGS=========
input int ma_period_stoch =7;  //Stochastic Period
input ENUM_TIMEFRAMES time_frame_stochastic = PERIOD_CURRENT; // Stochastic Time Frame
input double prev_stoch_low_value = 1.1;  // Prev. Day Stochastic Low value
input double prev_stoch_high_value = 1.33; //Prev. Day Stochastic High value
input double current_stoch_low_value = 2.9;  // Current Day Stochastic Low value
input double current_stoch_high_value = 4.35; //Current Day Stochastic High value

int atrvalue;
double atr_value[];

input string               p02                        ="";           //=====RSI SETTINGS=========
input int ma_period_rsi =7;  //RSI Period
input ENUM_TIMEFRAMES time_frame_rsi = PERIOD_CURRENT; // RSI Time Frame
input int rsi_high_value = 70; //Default RSI High value
input int rsi_low_value = 37;  // Default RSI Low value

int rsivalue;
double rsi_value[];



double tpoint, tradenow,bid, ask, spread_value,buy_sl, buy_tp, lot_size;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
    

    trade.SetExpertMagicNumber(MagicNumber);
    trade.SetDeviationInPoints(Slippage);
    trade.SetAsyncMode(false);
    
    
    if(Digits()==3 ||Digits()==5)  {tpoint = NormalizeDouble(Point()*10, Digits());}
    else tpoint=NormalizeDouble(Point(),Digits());
    
    atrvalue = iATR(Symbol(),time_frame_stochastic,ma_period_stoch); 
    rsivalue = iRSI(Symbol(),time_frame_rsi,ma_period_rsi,PRICE_CLOSE);
//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   ObjectsDeleteAll(0);
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---
    if(LotSize > 0) 
              {lot_size = LotSize;}
           else if(LotSize == -1) 
               {lot_size = AccountInfoDouble(ACCOUNT_BALANCE)/100;}
    ask=SymbolInfoDouble(Symbol(),SYMBOL_ASK);
    bid=SymbolInfoDouble(Symbol(),SYMBOL_BID);
    
    if(spread ==0 ) spread_value = SymbolInfoInteger(Symbol(),SYMBOL_SPREAD)*Point();
    else if(spread !=0) spread_value = spread; 
     
    ArraySetAsSeries(atr_value,true);
    CopyBuffer(atrvalue,0,0,ma_period_stoch,atr_value);
    //Comment(atr_value[0], " ", atr_value[1], " ", atr_value[2]);
    
    ArraySetAsSeries(rsi_value,true);
    CopyBuffer(rsivalue,0,0,ma_period_rsi,rsi_value);
    Comment(atr_value[0], " ", atr_value[1], " ", atr_value[2],
            "\n",rsi_value[0], " ", rsi_value[1], " ", rsi_value[2],
            "\nSpread: ", spread_value,
            "\nTakeProfit: ",NormalizeDouble(TakeProfit*tpoint, Digits()),
            "\nMaxLot: ",
            "\nLotsize: ",lot_size);//,lot_size
    
    if(IsNewCandle()){tradenow=1;}
      if(Allowed_position() < allowedposition && tradenow==1)
       if(atr_value[0] >= current_stoch_low_value && atr_value[0] <= current_stoch_high_value &&
          atr_value[1] >= prev_stoch_low_value    && atr_value[1] <= prev_stoch_high_value &&
          rsi_value[0] >= rsi_low_value           && rsi_value[0] <= rsi_high_value &&
          rsi_value[1] > rsi_value [0])
         { 
           
           if(trade.Buy(lot_size,NULL,ask,0,0,NULL))
             {
              ulong ticket = trade.ResultOrder();
              tradenow=0;
              set_tp(ticket);
             }
             
         }
     
  }
//+------------------------------------------------------------------+
//insuring its a new candle function                                 |
//+------------------------------------------------------------------+
bool IsNewCandle()
{
   static int BarsOnChart=0;
   
	if (Bars(_Symbol,PERIOD_CURRENT) == BarsOnChart)
	return (false);
	BarsOnChart = Bars(_Symbol,PERIOD_CURRENT);
	return(true);
}
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void set_tp(ulong tick)
   {
     int pt = PositionsTotal();
     
     for(int i=pt;i>=0;i--)
       {
        if(PositionSelectByTicket(tick))
          {
            if(PositionGetTicket(i)== tick && PositionGetInteger(POSITION_TYPE)==0)
              {
                buy_tp = PositionGetDouble(POSITION_PRICE_OPEN)+spread_value+(TakeProfit*tpoint);
                if(StopLoss == 0)buy_sl = 0;
                else if(StopLoss >0 ) buy_sl = PositionGetDouble(POSITION_PRICE_OPEN)- spread_value-(StopLoss*tpoint);
                
                trade.PositionModify(tick,buy_sl,buy_tp);
              }      
          }
       }
   }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int Allowed_position()
   {
     int open_position = 0;
     
     for(int i=PositionsTotal();i>=0;i--)
       {
        ulong tick = PositionGetTicket(i);
        if(PositionSelectByTicket(tick))
          {
            if(PositionGetString(POSITION_SYMBOL)== Symbol() && PositionGetInteger(POSITION_TYPE)==0 
            && PositionGetInteger(POSITION_MAGIC)==MagicNumber )
              {
                open_position++;
              }      
          }
       }
     return open_position;
   }
//+------------------------------------------------------------------+
